mytidy.penAFT: -@templateVar class penAFT

View source: R/penAFT-mytidy.R

mytidy.penAFTR Documentation

-@templateVar class penAFT

Description

-@template title_desc_tidy

Usage

## S3 method for class 'penAFT'
mytidy(x, return_zeros = FALSE, ...)

Arguments

x

A penAFT object returned from penAFT::penAFT().

'return_zeros'

Logical indicating whether coefficients with value zero zero should be included in the results. Defaults to FALSE.

  • @template param_unused_dots

Details

Note that while this representation of GLMs is much easier to plot and combine than the default structure, it is also much more memory-intensive. Do not use for large, sparse matrices.

No augment method is yet provided even though the model produces predictions, because the input data is not tidy (it is a matrix that may be very wide) and therefore combining predictions with it is not logical. Furthermore, predictions make sense only with a specific choice of lambda.

Value

A tibble::tibble() with columns:

dev.ratio

Fraction of null deviance explained at each value of lambda.

estimate

The estimated value of the regression term.

lambda

Value of penalty parameter lambda.

step

Which step of lambda choices was used.

df.step

The number of nonzero coefficients for each value of lambda. For multnet, the number of variables with a nonzero coefficient for any class.


agalecki/utilsag documentation built on Jan. 25, 2023, 5:36 a.m.