View source: R/penAFT-mytidy.R
| mytidy.penAFT | R Documentation |
-@template title_desc_tidy
## S3 method for class 'penAFT' mytidy(x, return_zeros = FALSE, ...)
x |
A |
'return_zeros' |
Logical indicating whether coefficients with value zero
zero should be included in the results. Defaults to
|
Note that while this representation of GLMs is much easier to plot and combine than the default structure, it is also much more memory-intensive. Do not use for large, sparse matrices.
No augment method is yet provided even though the model produces
predictions, because the input data is not tidy (it is a matrix that
may be very wide) and therefore combining predictions with it is not
logical. Furthermore, predictions make sense only with a specific
choice of lambda.
A tibble::tibble() with columns:
dev.ratio |
Fraction of null deviance explained at each value of lambda. |
estimate |
The estimated value of the regression term. |
lambda |
Value of penalty parameter lambda. |
step |
Which step of lambda choices was used. |
df.step |
The number of nonzero coefficients for each value of lambda. For multnet, the number of variables with a nonzero coefficient for any class. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.